@@ -3,10 +3,11 @@ import os.path
 import sys
 from pyspark import SparkContext
 from pyspark.mllib.classification import LogisticRegressionWithSGD
+from pyspark.mllib.regression import LabeledPoint
 from numpy import array
 
 if __name__ == "__main__":
-    data_file = '/spark/data/svm.txt'
+    data_file = '/spark/data/svm.data'
 
     if len(sys.argv) == 1:
         print >> sys.stderr, "Usage: classification.py <master>"
@@ -18,10 +19,7 @@ if __name__ == "__main__":
         parsedData = data.map(lambda line: array([float(x) for x in line.split(' ')]))
         model = LogisticRegressionWithSGD.train(parsedData)
 
-        # Build the model
-        labelsAndPreds = parsedData.map(lambda point: (int(point.item(0)),
-                                                       model.predict(point.take(range(1, point.size)))))
-
-        # Evaluating the model on training data
+        # Build the model and evaluate on training data. 
+        labelsAndPreds = parsedData.map(lambda p: (p.label, model.predict(p.features)))
         trainErr = labelsAndPreds.filter(lambda (v, p): v != p).count() / float(parsedData.count())
         print("Training Error = " + str(trainErr))
