@@ -39,8 +39,12 @@ class DockerManager(object):
     SSH_PORT = '22'
 
     def __init__(self):
+        # Figure out the cloud backend. For example,
+        # AWS, Openstack, local, etc. 
+        self.docker = self._get_system_backend()
+
         # Generate configuration.
-        self.config = ConfigFactory()
+        self.config = ConfigFactory(self.docker.system)
         self.resolver = DefaultResolver()
 
         # Service mappings
@@ -75,7 +79,6 @@ class DockerManager(object):
             }
 
         # Initialize the state. 
-        self.docker = self._get_system_backend()
         self._init_state_db()
         self._clean_state_db()
         logging.warning("using backend %s ver:%s " %(self.docker.name, self.docker.version()))
@@ -288,11 +291,18 @@ class DockerManager(object):
         """
         Inspect a running stack. 
         """
+
+        # Check if the cluster is running or not first.
+        cluster = self.cluster_collection.find_one( {'uuid': stack_uuid} )
+        if not cluster:
+            return None
+        elif cluster['status'] != 'running' and cluster['status'] != 'stopped':
+            return None
+
         json_reply = { 'uuid' : stack_uuid,
                        'status' : 'stack' }
 
         # Get the collection of all backends and connector UUIDS.
-        cluster = self.cluster_collection.find_one( {'uuid': stack_uuid} )
         json_reply['key'] = cluster['key']
         json_reply['base'] = cluster['base']
         json_reply['ts'] = str(cluster['ts'])
@@ -775,8 +785,8 @@ class DockerManager(object):
             container = c[0]
             from_dir = c[1]
             to_dir = c[2]
-            logging.warning("transfer config %s -> %s" % (from_dir, to_dir))
             self.docker.copy([container], from_dir, to_dir)
+            logging.warning("transferred config %s -> %s" % (from_dir, to_dir))
 
     def _transfer_ip(self, private_key, ips):
         """
@@ -800,8 +810,10 @@ class DockerManager(object):
         logging in (via ssh), we must place these variables in the profile. 
         """
         for k in env_vars.keys():
+            logging.warning("transferring env vars")
             self.docker.cmd(containers, 
                             "echo export %s=%s >> /etc/profile" % (k, env_vars[k]))
+        logging.warning("finished transfer env vars")
 
     def _start_containers(self, cluster_uuid, service_uuid, plan, ctype):
         """
